﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

namespace RadioButtonValidator
{
    public class RadioValidator : BaseValidator
    {

        public RadioValidator()
        {
          
        }

        protected override bool EvaluateIsValid()
        {
            return IsRadioButtonChecked(); 
        }

        protected override bool ControlPropertiesValid()
        {
            var control = FindControl(ControlToValidate) as RadioButton;
            return control != null; 
        }

        private bool IsRadioButtonChecked()
        {
            var radioButton = FindControl(ControlToValidate) as RadioButton;
            if(radioButton == null) throw new ArgumentNullException("Radio Button not found!");
            
            return radioButton.Checked; 
        }

      

        protected override void OnPreRender(EventArgs e)
        {
           // // register the resource 
            const string resourceName = "RadioButtonValidator.RadioButtonValidatorStyleSheet.css";

            var cssLink = new HtmlGenericControl("link") { ID = "cssLinkID" };
            cssLink.Attributes.Add("href", Page.ClientScript.GetWebResourceUrl(typeof(RadioValidator), resourceName));
            cssLink.Attributes.Add("rel", "stylesheet");
            cssLink.Attributes.Add("type", "text/css");
            Page.Header.Controls.Add(cssLink);

            // register javascript 
            const string jsResourceName = "RadioButtonValidator.RadioButtonValidatorClientSideFile.js";
             string jsScriptLocation = Page.ClientScript.GetWebResourceUrl(typeof(RadioValidator), jsResourceName);
            Page.ClientScript.RegisterClientScriptInclude("JSFile",jsScriptLocation);

            if (DetermineRenderUplevel() && EnableClientScript)
            {
                Page.ClientScript.RegisterExpandoAttribute(this.ClientID, "evaluationfunction", "isRadioButtonCheckedClientSide");

              // CreateJavaScript();
            }

            base.OnPreRender(e);
        }

      

        private void CreateJavaScript()
        {
            var sb = new StringBuilder();
            sb.Append(@" function isRadioButtonCheckedClientSide(ctrl) 
            {
                var rbSelect = document.getElementById(document.getElementById(ctrl.id).controltovalidate);
                var rf = document.getElementById(ctrl.id); 
                rf.className = 'radioButtonValidatorStyle'; 
                if(rbSelect.checked == false) return false; else return true; 
            }
");
            Page.ClientScript.RegisterClientScriptBlock(GetType(), "JSScript", sb.ToString(), true); 

        }
    }

   
}
